@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("../Dimension.js");
+include("scripts/Draw/Dimension/Dimension.js");
 
 /**
  * \class DimAngular
@@ -79,6 +79,7 @@ DimAngular.prototype.setState = function(state) {
         this.dimArcPosition = RVector.invalid;
         var trFirstEntity = qsTr("Arc or first of two lines");
         this.setLeftMouseTip(trFirstEntity);
+        this.setCommandPrompt(trFirstEntity);
         this.setRightMouseTip(EAction.trCancel);
         break;
 
@@ -92,6 +93,7 @@ DimAngular.prototype.setState = function(state) {
         this.dimArcPosition = RVector.invalid;
         var trSecondEntity = qsTr("Second line");
         this.setLeftMouseTip(trSecondEntity);
+        this.setCommandPrompt(trSecondEntity);
         this.setRightMouseTip(EAction.trBack);
         break;
 
